# Frequenz Python SDK

[<img alt="GitHub Workflow Status" src="https://img.shields.io/github/workflow/status/frequenz-floss/frequenz-sdk-python/frequenz-sdk-python">](https://github.com/frequenz-floss/frequenz-sdk-python/actions/workflows/ci.yaml)
[<img alt="PyPI" src="https://img.shields.io/pypi/v/frequenz-sdk">](https://pypi.org/project/frequenz-sdk/)
[<img alt="PyPI" src="https://img.shields.io/badge/docs-latest-informational">](https://frequenz-floss.github.io/frequenz-sdk-python/)

A development kit to interact with the Frequenz development platform.

## Supported Python versions

* For x86_64 Python 3.8 - 3.10 are supported (tested).
* For arm64 only Python 3.8 is supported (due to some dependencies that only support 3.8).

## Contributing

If you want to know how to build this project and contribute to it, please
check out the [Contributing Guide](CONTRIBUTING.md).
